package com.ruoyi.web.controller.priceVerification;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.quot.domain.Quot;
import com.ruoyi.quot.service.IQuotService;
import com.ruoyi.technicalConfirm.domain.QuotJsqr;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.priceVerification.domain.QuotHj;
import com.ruoyi.priceVerification.service.IQuotHjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 报价单-核价单Controller
 *
 * @author ruoyi
 * @date 2024-04-16
 */
@RestController
@RequestMapping("/priceVerification/priceVerification")
public class QuotHjController extends BaseController
{
    @Autowired
    private IQuotHjService quotHjService;

    @Autowired
    private IQuotService quotService;

    /**
     * 查询报价单-核价单列表
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:list')")
    @GetMapping("/list")
    public TableDataInfo list(QuotHj quotHj)
    {
        startPage();
        List<QuotHj> list = quotHjService.selectQuotHjList(quotHj);
        return getDataTable(list);
    }

    /**
     * 导出报价单-核价单列表
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:export')")
    @Log(title = "报价单-核价单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QuotHj quotHj)
    {
        List<QuotHj> list = quotHjService.selectQuotHjList(quotHj);
        ExcelUtil<QuotHj> util = new ExcelUtil<QuotHj>(QuotHj.class);
        util.exportExcel(response, list, "报价单-核价单数据");
    }

    /**
     * 获取报价单-核价单详细信息
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:query')")
    @GetMapping(value = "/{quotHjId}")
    public AjaxResult getInfo(@PathVariable("quotHjId") String quotHjId)
    {
        return success(quotHjService.selectQuotHjByQuotHjId(quotHjId));
    }

    /**
     * 新增报价单-核价单
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:add')")
    @Log(title = "报价单-核价单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QuotHj quotHj)
    {
        return toAjax(quotHjService.insertQuotHj(quotHj));
    }

    /**
     * 修改报价单-核价单
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:edit')")
    @Log(title = "报价单-核价单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QuotHj quotHj)
    {
        return toAjax(quotHjService.updateQuotHj(quotHj));
    }

    /**
     * 删除报价单-核价单
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:remove')")
    @Log(title = "报价单-核价单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{quotHjIds}")
    public AjaxResult remove(@PathVariable String[] quotHjIds)
    {
        return toAjax(quotHjService.deleteQuotHjByQuotHjIds(quotHjIds));
    }

    /**
     * 报价单-核价单 提交报价组
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:commit')")
    @Log(title = "报价单-核价单 提交报价组", businessType = BusinessType.UPDATE)
    @PostMapping("/commitHj")
    public AjaxResult commitHj(@RequestBody QuotHj quotHj) {

        quotHj.setUpdateBy(getUsername());
        quotHj.setQuotHjPricingDate(DateUtils.getNowDate());//报价单-核价单 核价日期设置为 当前日期
        quotHjService.updateQuotHj(quotHj);

        String quotHjId = quotHj.getQuotHjId();
        Quot quot = quotService.selectQuotByQuotHjId(quotHjId);
        quot.setQuotHjApprovalStatus("2");//报价单-核价单 状态设置为 已协助
        quotService.updateQuot(quot);

        return success();
    }

    /**
     * 报价单-核价单 驳回
     */
    @PreAuthorize("@ss.hasPermi('priceVerification:priceVerification:reject')")
    @Log(title = "报价单-核价单 驳回", businessType = BusinessType.OTHER)
    @PostMapping("/rejectHj")
    public AjaxResult rejectHj(@RequestBody QuotHj quotHj)
    {
        quotHj.setUpdateBy(getUsername());
        quotHjService.updateQuotHj(quotHj);

        String quotHjId = quotHj.getQuotHjId();
        Quot quot = quotService.selectQuotByQuotHjId(quotHjId);
        quot.setQuotHjApprovalStatus("3");
        quotService.updateQuot(quot);
        return success();
    }
}
