package com.ruoyi.web.controller.system;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.constant.WebsocketConst;
import com.ruoyi.framework.websocket.OneToManyWebSocket;
import com.ruoyi.framework.websocket.WebSocketServer;
import com.ruoyi.framework.websocket.WebSocketUsers;
import com.ruoyi.system.domain.SysNoticeUser;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysNotice;
import com.ruoyi.system.service.ISysNoticeService;

import javax.websocket.Session;

/**
 * 公告 信息操作处理
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/notice")
public class SysNoticeController extends BaseController
{
    @Autowired
    private ISysNoticeService noticeService;

    @Autowired
    private OneToManyWebSocket oneToManyWebSocket;

    /**
     * 获取通知公告列表
     */
    @PreAuthorize("@ss.hasPermi('system:notice:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysNotice notice)
    {
        startPage();
        List<SysNotice> list = noticeService.selectNoticeList(notice);
        return getDataTable(list);
    }

    /**
     * 根据通知公告编号获取详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:notice:query')")
    @GetMapping(value = "/{noticeId}")
    public AjaxResult getInfo(@PathVariable Long noticeId)
    {
        return success(noticeService.selectNoticeById(noticeId));
    }

    /**
     * 新增通知公告
     */
    @PreAuthorize("@ss.hasPermi('system:notice:add')")
    @Log(title = "通知公告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysNotice notice)
    {
        notice.setCreateBy(getUsername());
        noticeService.insertNotice(notice);
        //推送消息插入中间表
        Long userId = getLoginUser().getUserId();//当前登陆者
        insertNoticeUser(userId,notice,noticeService,oneToManyWebSocket,null);
        return success();
    }

    /**
     * 修改通知公告
     */
    @PreAuthorize("@ss.hasPermi('system:notice:edit')")
    @Log(title = "通知公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysNotice notice)
    {
        notice.setUpdateBy(getUsername());
        return toAjax(noticeService.updateNotice(notice));
    }

    /**
     * 删除通知公告
     */
    @PreAuthorize("@ss.hasPermi('system:notice:remove')")
    @Log(title = "通知公告", businessType = BusinessType.DELETE)
    @DeleteMapping("/{noticeIds}")
    public AjaxResult remove(@PathVariable Long[] noticeIds)
    {
        return toAjax(noticeService.deleteNoticeByIds(noticeIds));
    }

    /**
     * 导航面板 消息通知
     * @return
     */
    @GetMapping("/navbarNoticelist")
    public Map<String, List<SysNotice>> navbarNoticelist()
    {
        Long userId = getLoginUser().getUserId();//当前登陆者
        List<SysNotice> list = noticeService.navbarNoticelist(userId);
        Map<String, List<SysNotice>> groupedByNoticeType = list.stream()
                .collect(Collectors.groupingBy(SysNotice::getNoticeType));
        for(String key:groupedByNoticeType.keySet()){
            List<SysNotice> lt =  groupedByNoticeType.get(key);
            lt.sort((t1, t2) -> t2.getCreateTime().compareTo(t1.getCreateTime()));
        }
        return groupedByNoticeType;
    }

    /**
     * 导航面板 消息通知 获取详细信息
     */
    @GetMapping(value = "navbarNotice/{noticeId}")
    public AjaxResult getNavbarNoticeInfo(@PathVariable Long noticeId)
    {
        return success(noticeService.selectNoticeById(noticeId));
    }

    /**
     * 推送消息插入中间表
     * @param userId 发送对象排除自身
     * @param notice 发送信息对象
     * @param noticeService 接口
     * @param oneToManyWebSocket WebSocket服务
     */
    public static void insertNoticeUser(Long userId,SysNotice notice,ISysNoticeService noticeService,OneToManyWebSocket oneToManyWebSocket,List<String> userIds){
        List<SysNoticeUser> sysNoticeUsers = new ArrayList<SysNoticeUser>();

        JSONObject obj = new JSONObject();
        obj.put(WebsocketConst.MSG_ID, notice.getNoticeId());
        obj.put(WebsocketConst.MSG_TITLE, notice.getNoticeTitle());
        obj.put(WebsocketConst.MSG_CONTENT, notice.getNoticeContent());

        if(!"3".equals(notice.getNoticeType())){//系统通知 或 通知公告
            oneToManyWebSocket.sendMessage(obj.toString(),String.valueOf(userId));

            SysNoticeUser sysNoticeUser = null;
            Map<String, Session> users = oneToManyWebSocket.getUsers();//获取在线用户
            for(String userid:users.keySet()){
                if(!userid.equals(String.valueOf(userId))){
                    sysNoticeUser = new SysNoticeUser();
                    sysNoticeUser.setNoticeId(notice.getNoticeId());
                    sysNoticeUser.setUserId(Long.valueOf(userid));
                    sysNoticeUsers.add(sysNoticeUser);
                }
            }
            if(!sysNoticeUsers.isEmpty()){
                noticeService.insertNoticeUserBatch(sysNoticeUsers);
            }
        }else{
            if(userIds!=null&&userIds.size()>0){
                oneToManyWebSocket.sendMessageByUserIds(obj.toString(),userIds);

                SysNoticeUser sysNoticeUser = null;
                Map<String, Session> users = oneToManyWebSocket.getUsers();//获取在线用户
                for(String userid:users.keySet()){
                    if(userIds.contains(userid)){
                        sysNoticeUser = new SysNoticeUser();
                        sysNoticeUser.setNoticeId(notice.getNoticeId());
                        sysNoticeUser.setUserId(Long.valueOf(userid));
                        sysNoticeUsers.add(sysNoticeUser);
                    }
                }
                if(!sysNoticeUsers.isEmpty()){
                    noticeService.insertNoticeUserBatch(sysNoticeUsers);
                }
            }
        }
    }
}
