package com.ruoyi.priceVerification.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.priceVerification.mapper.QuotHjMapper;
import com.ruoyi.priceVerification.domain.QuotHj;
import com.ruoyi.priceVerification.service.IQuotHjService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 报价单-核价单Service业务层处理
 *
 * @author ruoyi
 * @date 2024-04-16
 */
@Service
public class QuotHjServiceImpl implements IQuotHjService
{
    @Autowired
    private QuotHjMapper quotHjMapper;

    /**
     * 查询报价单-核价单
     *
     * @param quotHjId 报价单-核价单主键
     * @return 报价单-核价单
     */
    @Override
    public QuotHj selectQuotHjByQuotHjId(String quotHjId)
    {
        return quotHjMapper.selectQuotHjByQuotHjId(quotHjId);
    }

    /**
     * 查询报价单-核价单列表
     *
     * @param quotHj 报价单-核价单
     * @return 报价单-核价单
     */
    @Override
    public List<QuotHj> selectQuotHjList(QuotHj quotHj)
    {
        return quotHjMapper.selectQuotHjList(quotHj);
    }

    /**
     * 新增报价单-核价单
     *
     * @param quotHj 报价单-核价单
     * @return 结果
     */
    @Transactional
    @Override
    public int insertQuotHj(QuotHj quotHj)
    {
        quotHj.setCreateTime(DateUtils.getNowDate());
        quotHj.setUpdateTime(DateUtils.getNowDate());
        return quotHjMapper.insertQuotHj(quotHj);
    }

    /**
     * 修改报价单-核价单
     *
     * @param quotHj 报价单-核价单
     * @return 结果
     */
    @Transactional
    @Override
    public int updateQuotHj(QuotHj quotHj)
    {
        quotHj.setUpdateTime(DateUtils.getNowDate());
        return quotHjMapper.updateQuotHj(quotHj);
    }

    /**
     * 批量删除报价单-核价单
     *
     * @param quotHjIds 需要删除的报价单-核价单主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteQuotHjByQuotHjIds(String[] quotHjIds)
    {
        return quotHjMapper.deleteQuotHjByQuotHjIds(quotHjIds);
    }

    /**
     * 删除报价单-核价单信息
     *
     * @param quotHjId 报价单-核价单主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteQuotHjByQuotHjId(String quotHjId)
    {
        return quotHjMapper.deleteQuotHjByQuotHjId(quotHjId);
    }
}
